.. This file is automatically generated/updated by a github actions workflow.
.. Every manual change will be overwritten on push to main.
.. You can find it here: ``.github/workflows/update-authors.yaml``
.. For more information see `https://github.com/myint/rstcheck/graphs/contributors`

Author
------
Steven Myint <git@stevenmyint.com>

Additional contributions by (sorted by name)
--------------------------------------------
- Changxu Wang <Changxu.mail@gmail.com>
- Christian Riedel <cielquan@protonmail.com>
- Daniel M. Capella <polyzen@users.noreply.github.com>
- Dmitry <root@uralbash.ru>
- Eugene Lorman <eugene.lorman@gmail.com>
- Jochen Sprickerhof <git@jochen.sprickerhof.de>
- John Vandenberg <jayvdb@gmail.com>
- Kagami Sascha Rosylight <saschanaz@outlook.com>
- Keith Maxwell <keith.maxwell@gmail.com>
- LCD 47 <lcd047@gmail.com>
- Maël Pedretti <73VW@users.noreply.github.com>
- Michael Fladischer <FladischerMichael@fladi.at>
- Michael Goerz <goerz@stanford.edu>
- Sameer Singh <sam7thegreat@gmail.com>
- Santos Gallegos <santos_g@outlook.com>
- Svintsov Dmitry <root@uralbash.ru>
- Timo Röhling <timo@gaussglocke.de>
- biscuitsnake <11334474+biscuitsnake@users.noreply.github.com>
